@@ -46,9 +46,7 @@ class Post(models.Model):
         return Tag.objects.get_for_object(self)
 
     def get_absolute_url(self):
-        current_site = Site.objects.get(id=conf.SITE_ID)
-        myurl = "http://"+current_site.domain
-        return myurl + reverse('app_blog-post-detail', kwargs={'slug': self.slug})
+        return reverse('app_blog-post-detail', kwargs={'slug': self.slug})
 
     def __unicode__(self):
         return self.title
