@@ -8,7 +8,8 @@ from django.contrib.sites.models import Site
 
 register = template.Library()
 
-def backlinks_list(request):
+@register.inclusion_tag('elements/backlinks_list.html')
+def backlinks_list():
     OpenInNewWindow = "1"
     BLKey = conf.KEY_BACKLINKS
     current_site = Site.objects.get(id=conf.SITE_ID)
@@ -34,9 +35,15 @@ def backlinks_list(request):
     for search, replace in edits:
         output_code = output_code.replace(search, replace)
 
-    
     return {
         'links': output_code
     }
 
-register.inclusion_tag('elements/backlinks_list.html')(backlinks_list)
+"""
+Template:
+{% load cache %}
+
+{% cache 21600 backlinks %}
+{{ links|safe }}
+{% endcache %}
+"""
